#
# spec file for package perl-PAR-Dist
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name PAR-Dist
Name:           perl-PAR-Dist
Version:        0.52
Release:        1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Create and manipulate PAR distributions
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RS/RSCHUPP/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module creates and manipulates _PAR distributions_. They are
architecture-specific *PAR* files, containing everything under _blib/_ of
CPAN distributions after their 'make' or 'Build' stage, a _META.yml_
describing metadata of the original CPAN distribution, and a _MANIFEST_
detailing all files within it. Digitally signed PAR distributions will also
contain a _SIGNATURE_ file.

The naming convention for such distributions is:

    $NAME-$VERSION-$ARCH-$PERL_VERSION.par

For example, 'PAR-Dist-0.01-i386-freebsd-5.8.0.par' corresponds to the 0.01
release of 'PAR-Dist' on CPAN, built for perl 5.8.0 running on
'i386-freebsd'.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Mon May  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.52
  see /usr/share/doc/packages/perl-PAR-Dist/Changes
  0.52  2023-06-07
  - change bugtracker to GitHub issues
  - quote all version numbers in META.yml files in test *.par
    files to avoid CPAN Testers failures like
    http://www.cpantesters.org/cpan/report/973fa832-ec54-11ed-98b0-b3c3213a625c
* Tue Dec  1 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.51
  see /usr/share/doc/packages/perl-PAR-Dist/Changes
  0.51  2020-11-30
  - Fix problem with Cwd::realpath()
    Some versions of Cwd::realpath() must be called on an *existing* path,
    otherwise they will return undef.
* Wed Nov 18 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.50
  see /usr/share/doc/packages/perl-PAR-Dist/Changes
* Sat Jun  8 2013 coolo@suse.com
- updated to 0.49
  * Fix RT #78194: PAR::Dist::parse_dist_name mis-parses par file name
    Patch from KENO, thanks!
* Tue Nov 29 2011 coolo@suse.com
- update to 0.48
  * Prefer MYMETA.yml over META.yml if possible.
  * Try YAML implementations in different order (XS first).
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Sep  6 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- rewrote auto-generated spec file
- update to 0.47:
  * POD fixes
  * do not use Archive::Zip if its version is 1.28
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sat Jun 27 2009 chris@computersalat.de
- initial pkg 0.45
